@@ -34,6 +34,7 @@ public:
     }
     void attachPopup(QtWaylandClient::QWaylandShellSurface *popup) override;
 
+    void setDesiredSize(const QSize &size);
     void setAnchor(uint32_t anchor);
     void setExclusiveZone(int32_t zone);
     void setExclusiveEdge(uint32_t edge);
@@ -62,6 +63,7 @@ private:
     QString m_activationToken;
 
     bool m_configured = false;
+    bool m_configuring = false;
 
     static const wl_callback_listener syncCallbackListener;
     struct wl_callback *m_waitForSyncCallback = nullptr;
